#
#  deploy.py
#  UILib
#
#  Created by Mark Burkart on 1/17/12.
#  Copyright (c) 2012 PopCap Games. All rights reserved.
#
#  This script should be used as a guide for projects.
#  Handles deploying the data exported from Placerator to the target project.
#
#  Removes all previously deployed data
#  Copies Image assets to (TARGET_IMAGE_DIR)/NonResize/Export
#  Copies Font assets to (TARGET_FONT_DIR)/NonResize/Export
#  Copies ExportProps.txt to (TARGET_RESPROPS_DIR)
#  Copies export.uidata to (TARGET_DIST_DIR)
#






import sys
import shutil
import os
import zipfile
	
# srcPath is the Path to the .zip file to be deployed to the project.
srcPath = 'none'

# destPath is the root director of the project. doesn't matter what that is just need to
# have the relative paths below set up appropriately.
destPath = 'none'

# --CUSTOM PROJECT PATHS
# Target paths should be relative to destPath
TARGET_IMAGE_DIR = "res/common/images/"
TARGET_FONT_DIR = "res/common/fonts/"
TARGET_RESPROPS_DIR = "resprops/"
TARGET_DIST_DIR = "dist/mac/"
# --CUSTOM PROJECT PATHS

if (len(sys.argv) > 2):
	srcPath = sys.argv[1]
	destPath = sys.argv[2]

print srcPath
if not zipfile.is_zipfile(srcPath):
	print "INVALID SOURCE FILE"
	sys.exit();

if not destPath.endswith("/"):
    destPath += "/"

srcFontPath = "FONT/EXPORT/"
srcImagePath = "IMAGE/EXPORT/"


destUIDataPath = destPath + TARGET_DIST_DIR
destUIDataFile = destUIDataPath + "export.uidata"
destImageDir = destPath + TARGET_IMAGE_DIR + "NonResize/Export"
destFontDir = destPath + TARGET_FONT_DIR + "NonResize/Export"
destResPropsPath = destPath + TARGET_RESPROPS_DIR


print "FONTS_DIR = " + destFontDir
print "IMAGE_DIR = " + destImageDir
print "DIST_DIR = " + destUIDataPath
print "RESPROPS_DIR = " +destResPropsPath


try:
	print "Removing Old Fonts " + destFontDir
	shutil.rmtree(destFontDir)
except:
	print "Failed To Remove Old Fonts"
	pass

try:
	print "Removing Old Images " + destImageDir
	shutil.rmtree(destImageDir)
except:
	print "Failed To Remove Old Images"
	pass

try:
	os.remove(destUIDataFile)
except:
	print "Failed to remove .uidata"
	pass


# extract the exported archive
print "Extracting package"
pkg = zipfile.ZipFile(srcPath, "r")
pkg.extractall("/tmp/extract/")

print "Moving ResProps Data"
shutil.copy("/tmp/extract/RES_PROPS.txt", destResPropsPath);

print "Moving export.uidata"
shutil.copy("/tmp/extract/export.uidata",destUIDataFile)

print "Moving Fonts"
try:
	shutil.move("/tmp/extract/FONT/EXPORT/", destFontDir)
except:
	print "Font Copy Failed"
	pass


print "Moving Images"
try:
	shutil.move("/tmp/extract/IMAGE/EXPORT/", destImageDir)
except:
	print "Image Copy Failed"
pass

print "Cleaning Up"
shutil.rmtree("/tmp/extract/")

print "Finished!"